netapp_ontap.models.volume_movement API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_movement`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeMovementSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeMovement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `capacity_tier_optimized: bool GET PATCH`

    Specifies whether this move should perform optimized volume move for the capacity tier, in which data in the capacity tier does not need to be copied over.

  `cutover_window: Size GET PATCH`

    Time window in seconds for cutover. The allowed range is between 30 to 300 seconds.

    Example: 30

  `destination_aggregate: Aggregate GET PATCH`

    The destination_aggregate field of the volume_movement.

  `percent_complete: Size GET`

    Completion percentage

  `start_time: ImpreciseDateTime GET`

    Start time of volume move.

    Example: 2020-12-07T08:45:12.000+0000

  `state: str GET PATCH`

    State of volume move operation. PATCH the state to "aborted" to abort the move operation. PATCH the state to "cutover" to trigger cutover. PATCH the state to "paused" to pause the volume move operation in progress. PATCH the state to "replicating" to resume the paused volume move operation. PATCH the state to "cutover_wait" to go into cutover manually. When volume move operation is waiting to go into "cutover" state, this is indicated by the "cutover_pending" state. A change of state is only supported if volume movement is in progress.

    Valid choices:

    - aborted
    - cutover
    - cutover_wait
    - cutover_pending
    - failed
    - paused
    - queued
    - replicating
    - success
  `tiering_policy: str GET PATCH`

    Tiering policy for FabricPool

    Valid choices:

    - all
    - auto
    - backup
    - none
    - snapshot_only